import classNames from 'classnames'
import CloseIcon from 'mdi-react/CloseIcon'
import React from 'react'

import { Badge } from '@sourcegraph/wildcard'

import { useTemporarySetting } from '../../settings/temporary/useTemporarySetting'

import styles from './VulnerabilityAnnouncement.module.scss'

/**
 * Displays a dismissible banner linking to the log4j blog post
 */
export const VulnerabilityAnnouncement: React.FunctionComponent = () => {
    const [visible, setVisible] = useTemporarySetting('dotcom.log4jVulnerabilityAnnouncement.visible', true)
    return (
        <div className="w-100 d-flex justify-content-center">
            {visible ? (
                <div className="d-flex justify-content-center">
                    <div className={classNames('card', styles.ctaCard)}>
                        <a
                            href="https://about.sourcegraph.com/blog/log4j-log4shell-0-day/"
                            target="_blank"
                            rel="noopener noreferrer"
                            className="d-flex align-items-center"
                        >
                            <Badge variant="info" className="text-uppercase mr-2">
                                Important
                            </Badge>

                            <span>
                                Read our blog post on how to find <strong>Log4j</strong> vulnerabilities in your code,
                                including example queries.
                            </span>
                        </a>
                        <button
                            type="button"
                            aria-label="Close alert"
                            className={classNames('btn btn-icon ml-2', styles.closeButton)}
                            onClick={() => setVisible(false)}
                        >
                            <CloseIcon className="icon-inline" />
                        </button>
                    </div>
                </div>
            ) : null}
        </div>
    )
}
